@@ -22,7 +22,7 @@ use File::Basename ();
 use File::Path ();
 
 # ABSTRACT: Test an imaginary beowulf cluster of Clustericious services
-our $VERSION = '0.28'; # VERSION
+our $VERSION = '0.29'; # VERSION
 
 
 BEGIN { $ENV{MOJO_LOG_LEVEL} = 'fatal' }
@@ -401,6 +401,25 @@ sub create_cluster_ok
       });
     }
 
+    if($app && $app->isa('Clustericious::App'))
+    {
+      my $fn = $app_name;
+      $fn =~ s{::}{-}g;
+      $fn = "$home/etc/$fn.conf";
+      unless(-e $fn)
+      {
+        # YAML::XS is a prereq for Clustericious
+        # so we can use it here.
+        require YAML::XS;
+        my %config = %{ $app->config };
+        $config{url} //= $self->url->to_string;
+        my $payload = YAML::XS::Dump(\%config);
+        open my $fh, '>', $fn;
+        print $fh $payload;
+        close $fh;
+      }
+    }
+
     $cb->() if defined $cb;
   }
 
@@ -625,6 +644,23 @@ sub extract_data_section
   $class;
 }
 
+
+sub client
+{
+  my($self, $n) = @_;
+  my $app = $self->apps->[$n];
+  return unless eval { $app->isa('Clustericious::App') };
+  my $client_class = ref($app) . '::Client';
+  unless($client_class->can('new') || eval qq{ require $client_class; $client_class->isa('Clustericious::Client') })
+  {
+    require Clustericious::Client;
+    $client_class = 'Clustericious::Client';
+  }
+  my %config = %{ $app->config };
+  $config{url} = $self->urls->[$n];
+  my $client = $client_class->new( config => Clustericious::Config->new(\%config) );
+}
+
 1;
 
 __END__
@@ -639,7 +675,7 @@ Test::Clustericious::Cluster - Test an imaginary beowulf cluster of Clustericiou
 
 =head1 VERSION
 
-version 0.28
+version 0.29
 
 =head1 SYNOPSIS
 
@@ -965,6 +1001,17 @@ Extract the files from the data section of the current package
 that match the given regex.  C<$regex> can also be a plain
 string for an exact filename match.
 
+=head2 client
+
+ my $client = $cluster->client($n);
+
+Return a L<Clustericious::Client> object for use with the C<$n>th
+service in the cluster.  If there is a corresponding C<YourService::Client>
+class then it will be used.  Otherwise you will get a generic
+L<Clustericious::Client> object with the correct URL configured.
+
+This method only works with L<Clustericious> services.
+
 =head1 CAVEATS
 
 Some combination of Mojolicious, FreeBSD, IPv6 and TLS/SSL
